@@ -1,13 +1,13 @@
 # coding=utf-8
 """
-Docs:
+Docs for different language:
     中文: https://rhythmlian.cn/2020/08/09/QuickStart-Rhy-zh/
 
     English: https://rhythmlian.cn/2020/02/14/QuickStart-Rhy/
 """
 import os
 import sys
-from .__config__ import QsConfig, dir_char, system
+from .__config__ import QsConfig, QsCache, dir_char, system
 from .NetTools import headers
 from rich.console import Console
 from rich.prompt import Prompt as qs_default_input
@@ -16,6 +16,7 @@ name = 'QuickStart_Rhy'
 
 user_root = os.path.expanduser('~') + dir_char
 qs_config = QsConfig(user_root + '.qsrc', os.path.exists(user_root + '.qsrc'))
+qs_cache = QsCache(user_root + '.qs_cache')
 
 user_lang = qs_config.basicSelect('default_language')
 user_currency = qs_config.basicSelect('default_currency')
@@ -26,9 +27,10 @@ qs_error_string = f'[bold red][{"ERROR" if user_lang != "zh" else "错误"}]'
 qs_warning_string = f'[bold yellow][{"WARNING" if user_lang != "zh" else "警告"}]'
 qs_info_string = f'[bold cyan][{"INFO" if user_lang != "zh" else "提示"}]'
 qs_default_console = Console()
+qs_console_width = qs_default_console.width
 
 
-def requirePackage(pname: str, module: str = "", real_name: str = "", not_exit: bool = True):
+def requirePackage(pname: str, module: str = "", real_name: str = "", not_exit: bool = True, not_ask: bool = False):
     """
     获取本机上的python第三方库
 
@@ -40,7 +42,9 @@ def requirePackage(pname: str, module: str = "", real_name: str = "", not_exit:
     """
     try:
         exec(f'from {pname} import {module}' if module else f"import {pname}")
-    except Exception:
+    except (ModuleNotFoundError, ImportError):
+        if not_ask:
+            return None
         from PyInquirer import prompt
 
         confirm = prompt({
@@ -179,7 +183,7 @@ def open_app():
     :return: None
     """
     if system == 'darwin':
-        os.system('open -a ' + ' '.join(sys.argv[2:]))
+        os.system('open -a ' + ' '.join([i.replace(' ', '\\ ') for i in sys.argv[2:]]))
     else:
         qs_default_console.print(qs_error_string, '"-a" is only support Mac OS X')
 
@@ -193,9 +197,9 @@ def open_file(argv=None):
     :return: None
     """
     if not argv:
-        argv = sys.argv[2:]
+        argv = [i.replace(' ', '\\ ') for i in sys.argv[2:]]
     if system == 'darwin':
-        os.system('open "' + '" "'.join(argv) + '"')
+        os.system('open ' + ' '.join(argv))
     elif system == 'linux':
         from subprocess import run
         run(['xdg-open'] + [i for i in argv])
